@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '1.02';
+  $CPAN::Perl::Releases::VERSION = '1.04';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -244,6 +244,10 @@ our $data =
     "tar.bz2" => "D/DA/DAPM/perl-5.14.4-RC2.tar.bz2",
     "tar.gz" => "D/DA/DAPM/perl-5.14.4-RC2.tar.gz",
   },
+  "5.14.4" => {
+    "tar.bz2" => "D/DA/DAPM/perl-5.14.4.tar.bz2",
+    "tar.gz" => "D/DA/DAPM/perl-5.14.4.tar.gz",
+  },
   "5.15.0" => {
     "tar.bz2" => "D/DA/DAGOLDEN/perl-5.15.0.tar.bz2",
     "tar.gz" => "D/DA/DAGOLDEN/perl-5.15.0.tar.gz",
@@ -467,7 +471,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.02
+version 1.04
 
 =head1 SYNOPSIS
 
